==> anwiba-commons-xml-1.1.121-sources.jar: net/anwiba/commons/xml/io/IRegistableConvertingXmlWriter.java <==
/*
 * #%L
 * anwiba commons advanced
 * %%
 * Copyright (C) 2007 - 2016 Andreas Bartels
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-2.1.html>.
 * #L%
 */

package net.anwiba.commons.xml.io;

import java.io.IOException;
import java.io.OutputStream;

import net.anwiba.commons.lang.functional.IApplicable;
import net.anwiba.commons.utilities.parameter.IParameters;
import net.anwiba.commons.utilities.parameter.Parameters;
import net.anwiba.commons.utilities.property.IProperties;
import net.anwiba.commons.utilities.property.PropertiesBuilder;

public interface IRegistableConvertingXmlWriter<C, T> extends IApplicable<C> {

  default void write(final T object, final OutputStream outputStream) throws IOException {
    write(object, Parameters.empty(), outputStream, new PropertiesBuilder().build());
  }

  void write(T object, IParameters parameter, OutputStream outputStream, IProperties outputProperties)
      throws IOException;

}

==> anwiba-commons-xml-1.1.158-sources.jar: net/anwiba/commons/xml/io/IRegistableConvertingXmlWriter.java <==
/*
 * #%L
 * anwiba commons advanced
 * %%
 * Copyright (C) 2007 - 2016 Andreas Bartels
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-2.1.html>.
 * #L%
 */

package net.anwiba.commons.xml.io;

import java.io.IOException;
import java.io.OutputStream;

import net.anwiba.commons.lang.functional.IApplicable;
import net.anwiba.commons.lang.parameter.IParameters;
import net.anwiba.commons.lang.parameter.Parameters;
import net.anwiba.commons.utilities.property.IProperties;
import net.anwiba.commons.utilities.property.PropertiesBuilder;

public interface IRegistableConvertingXmlWriter<C, T> extends IApplicable<C> {

  default void write(final T object, final OutputStream outputStream) throws IOException {
    write(object, Parameters.empty(), outputStream, new PropertiesBuilder().build());
  }

  void write(T object, IParameters parameter, OutputStream outputStream, IProperties outputProperties)
      throws IOException;

}
